@@ -1,7 +1,7 @@
 package Getopt::Long::Util;
 
-our $DATE = '2016-10-21'; # DATE
-our $VERSION = '0.85'; # VERSION
+our $DATE = '2016-10-26'; # DATE
+our $VERSION = '0.86'; # VERSION
 
 use 5.010001;
 use strict;
@@ -274,11 +274,24 @@ sub detect_getopt_long_script {
             $reason = "Does not have 'perl' in the shebang line";
             last;
         }
-        if ($str =~ /^\s*(use|require)\s+(Getopt::Long(?:::Complete)?)(\s|;)/m) {
-            $yesno = 1;
-            $extrameta{'func.module'} = $2;
-            last DETECT;
+
+        # NOTE: the presence of \s* pattern after ^ causes massive slowdown of
+        # the regex when we reach many thousands of lines, so we use split()
+
+        #if ($str =~ /^\s*(use|require)\s+(Getopt::Long(?:::Complete)?)(\s|;)/m) {
+        #    $yesno = 1;
+        #    $extrameta{'func.module'} = $2;
+        #    last DETECT;
+        #}
+
+        for (split /^/, $str) {
+            if (/^\s*(use|require)\s+(Getopt::Long(?:::Complete)?)(\s|;|$)/) {
+                $yesno = 1;
+                $extrameta{'func.module'} = $2;
+                last DETECT;
+            }
         }
+
         $reason = "Can't find any statement requiring Getopt::Long(?::Complete)? module";
     } # DETECT
 
@@ -299,7 +312,7 @@ Getopt::Long::Util - Utilities for Getopt::Long
 
 =head1 VERSION
 
-This document describes version 0.85 of Getopt::Long::Util (from Perl distribution Getopt-Long-Util), released on 2016-10-21.
+This document describes version 0.86 of Getopt::Long::Util (from Perl distribution Getopt-Long-Util), released on 2016-10-26.
 
 =head1 FUNCTIONS
 
@@ -442,7 +455,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Getopt-Lon
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Getopt-Long-Util>.
+Source repository is at L<https://github.com/sharyanto/perl-Getopt-Long-Util>.
 
 =head1 BUGS
 
